==> glexec-0.8.10.tar.gz: glexec-0.8.10/src/glexec_lcmaps.h <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 * Authors: Oscar Koeroo, Mischa Sall\'e
 *      NIKHEF Amsterdam, the Netherlands
 *      <grid-mw-security@nikhef.nl>  
 */

#ifndef _GLEXEC_LCMAPS_H
#define _GLEXEC_LCMAPS_H

/*
 * \file glexec_lcmaps.h
 * provides the functionality to dynamically open lcmaps and its API
 */

/* For glexec_account_t */
#include "glexec.h"

/* For type FILE */
#include <stdio.h>

/*************************************************************************/
/* LCMAPS DEFAULTS							 */
/*************************************************************************/

/* Default db file is set in configure */

#ifndef LCMAPS_LOG_FILE
#define LCMAPS_LOG_FILE "/var/log/glexec/lcas_lcmaps.log"
#endif

#ifndef LCMAPS_DEBUG_LEVEL
#define LCMAPS_DEBUG_LEVEL   "0"
#endif

/* LCMAPS_LIBDIR is used to search the liblcmaps*.so files, when set to "", the
 * system default search path is used (ld.so.conf etc.) */
#ifndef LCMAPS_LIBDIR
#define LCMAPS_LIBDIR	""
#endif

#ifndef LCMAPS_POLICY_NAME
#define LCMAPS_POLICY_NAME  ""
#endif

#ifndef LIBSUFF
 #ifdef __APPLE__
  #define LIBSUFF       ".dylib"
 #else
  #define LIBSUFF       ".so"
 #endif
#endif

/*************************************************************************/
/* FUNCTION DECLARATIONS                                                 */
/*************************************************************************/

/*
 * Setup, run and close LCMAPS, returning a target account
 * returns GLEXEC_SUCCESS when successful
 */
int glexec_lcmaps(char *pem_string, char *logstring,
		  glexec_account_t *target_account);

/*
 * Print the known LCMAPS defines to given open file descriptor.
 */
void glexec_lcmaps_defines(FILE *out);

#endif

==> glexec_0.9.8.orig.tar.gz: glexec-0.9.8/src/glexec_lcmaps.h <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 * Authors: Oscar Koeroo, Mischa Sall\'e
 *      NIKHEF Amsterdam, the Netherlands
 *      <grid-mw-security@nikhef.nl>  
 */

#ifndef _GLEXEC_LCMAPS_H
#define _GLEXEC_LCMAPS_H

/*
 * \file glexec_lcmaps.h
 * provides the functionality to dynamically open lcmaps and its API
 */

/* For glexec_account_t */
#include "glexec.h"

/* For type FILE */
#include <stdio.h>

/*************************************************************************/
/* LCMAPS DEFAULTS							 */
/*************************************************************************/

/* Default db file is set in configure */

#ifndef LCMAPS_LOG_FILE
#define LCMAPS_LOG_FILE "/var/log/glexec/lcas_lcmaps.log"
#endif

#ifndef LCMAPS_DEBUG_LEVEL
#define LCMAPS_DEBUG_LEVEL   "4"
#endif

/* LCMAPS_LIBDIR is used to search the liblcmaps*.so files, when set to "", the
 * system default search path is used (ld.so.conf etc.) */
#ifndef LCMAPS_LIBDIR
#define LCMAPS_LIBDIR	""
#endif

#ifndef LCMAPS_POLICY_NAME
#define LCMAPS_POLICY_NAME  ""
#endif

#ifndef LIBSUFF
 #ifdef __APPLE__
  #define LIBSUFF       ".dylib"
 #else
  #define LIBSUFF       ".so"
 #endif
#endif

/*************************************************************************/
/* FUNCTION DECLARATIONS                                                 */
/*************************************************************************/

/*
 * Setup, run and close LCMAPS, returning a target account
 * returns GLEXEC_SUCCESS when successful
 */
int glexec_lcmaps(char *pem_string, glexec_account_t *target_account);

/*
 * Print the known LCMAPS defines to given open file descriptor.
 */
void glexec_lcmaps_defines(FILE *out);

#endif
